If you'd like to report a bug in Flask-Appbuilder, fill out the template below. Provide
any extra information that may be useful

Responsible disclosure:
We want to keep Flask-AppBuilder safe for everyone. If you've discovered a security vulnerability
please report to danielvazgaspar@gmail.com.

### Environment

Flask-Appbuilder version:

pip freeze output:

### Describe the expected results

Tell us what should happen.

```python
Paste a minimal example that causes the problem.
```

### Describe the actual results

Tell us what happens instead.

```pytb
Paste the full traceback if there was an exception.
```

### Steps to reproduce

